@@ -5,7 +5,6 @@ import os
 import queue
 import sys
 import logging
-import re
 from . import hook
 from oocana import Mainframe, ServiceExecutePayload
 from .utils import run_in_new_thread, run_async_code, oocana_dir
@@ -20,9 +19,9 @@ service_store: dict[str, Literal["launching", "running"]] = {}
 job_set = set()
 
 # 日志目录 ~/.oocana/sessions/{session_id}
-# executor 的日志都会记录在 [python-executor-{suffix}.log | python-executor.log]
-# 全局 logger 会记录在 python-{suffix}.log | python.log
-def config_logger(session_id: str, suffix: str | None, output: Literal["console", "file"]):
+# executor 的日志都会记录在 [python-executor-{identifier}.log | python-executor.log]
+# 全局 logger 会记录在 python-{identifier}.log | python.log
+def config_logger(session_id: str, identifier: str | None, output: Literal["console", "file"]):
 
 
     format = '%(asctime)s - %(levelname)s - {%(pathname)s:%(lineno)d} - %(message)s'
@@ -30,7 +29,7 @@ def config_logger(session_id: str, suffix: str | None, output: Literal["console"
     logger.setLevel(logging.DEBUG)
     if output == "file":
         executor_dir = os.path.join(oocana_dir(), "sessions", session_id)
-        logger_file = os.path.join(executor_dir, f"python-executor-{suffix}.log") if suffix is not None else os.path.join(executor_dir, "python-executor.log")
+        logger_file = os.path.join(executor_dir, f"python-executor-{identifier}.log") if identifier is not None else os.path.join(executor_dir, "python-executor.log")
 
         if not os.path.exists(logger_file):
             os.makedirs(os.path.dirname(logger_file), exist_ok=True)
@@ -38,7 +37,7 @@ def config_logger(session_id: str, suffix: str | None, output: Literal["console"
         print(f"setup logging in file {logger_file}")
         h = logging.FileHandler(logger_file)
 
-        global_logger_file = os.path.join(executor_dir, f"python-{suffix}.log") if suffix is not None else os.path.join(executor_dir, "python.log")
+        global_logger_file = os.path.join(executor_dir, f"python-{identifier}.log") if identifier is not None else os.path.join(executor_dir, "python.log")
         logging.basicConfig(filename=global_logger_file, level=logging.DEBUG, format=format)
     else:
         logging.basicConfig(level=logging.DEBUG, format=format)
@@ -50,10 +49,10 @@ def config_logger(session_id: str, suffix: str | None, output: Literal["console"
     logger.propagate = False
 
 
-async def run_executor(address: str, session_id: str, package: str | None, session_dir: str, suffix: str | None = None):
+async def run_executor(address: str, session_id: str, package: str | None, session_dir: str, identifier: str | None = None):
 
-    if suffix is not None:
-        mainframe = Mainframe(address, f"python-executor-{suffix}", logger)
+    if identifier is not None:
+        mainframe = Mainframe(address, f"python-executor-id-{identifier}", logger)
     else:
         mainframe = Mainframe(address, f"python-executor-{session_id}", logger)
 
@@ -69,8 +68,7 @@ async def run_executor(address: str, session_id: str, package: str | None, sessi
 
     # add package to sys.path
     if package is not None:
-        # TODO: compatibility for package with prefix. e.g. package-/app/workspace. remove it after new version of oocana
-        sys.path.append(re.sub(r"^.*?/", "/", package))
+        sys.path.append(package)
     elif os.path.exists("/app/workspace"):
         sys.path.append("/app/workspace")
 
@@ -78,8 +76,8 @@ async def run_executor(address: str, session_id: str, package: str | None, sessi
     def not_current_session(message):
         return message.get("session_id") != session_id
     
-    def not_current_package(message):
-        return message.get("package") != package
+    def not_current_job(message):
+        return message.get("identifier") != identifier
 
     # 目前的 mqtt 库，在 subscribe 回调里 publish 消息会导致死锁无法工作，参考 https://github.com/eclipse/paho.mqtt.python/issues/527 或者 https://stackoverflow.com/a/36964192/4770006
     # 通过这种方式来绕过，所有需要 callback 后 publish message 的情况，都需要使用 future 类似方式来绕过。
@@ -90,7 +88,7 @@ async def run_executor(address: str, session_id: str, package: str | None, sessi
         if not_current_session(message):
             return
 
-        if not_current_package(message):
+        if not_current_job(message):
             return
         
         # https://github.com/oomol/oocana-rust/issues/310 临时解决方案
@@ -109,7 +107,7 @@ async def run_executor(address: str, session_id: str, package: str | None, sessi
         if not_current_session(message):
             return
         
-        if not_current_package(message):
+        if not_current_job(message):
             return
 
         nonlocal fs
@@ -146,7 +144,7 @@ async def run_executor(address: str, session_id: str, package: str | None, sessi
     mainframe.subscribe(exit_report_topic(), service_exit)
     mainframe.subscribe(status_report_topic(), service_status)
 
-    mainframe.notify_executor_ready(session_id, EXECUTOR_NAME, package)
+    mainframe.notify_executor_ready(session_id, EXECUTOR_NAME, package, identifier)
 
     async def spawn_service(message: ServiceExecutePayload, service_hash: str):
         logger.info(f"create new service {message.get('dir')}")
@@ -230,20 +228,26 @@ def main():
     parser.add_argument("--session-dir", help="a tmp dir for whole session", required=True)
     parser.add_argument("--output", help="output log to console or file", default="file", choices=["console", "file"])
     parser.add_argument("--package", help="package path, if set, executor will only run same package block", default=None)
-    parser.add_argument("--suffix", help="suffix for log file", default=None)
+    parser.add_argument("--identifier", help="identifier for executor, oocana will think same identifier as one executor", default=None)
 
-    args = parser.parse_args()
+    try:
+        args = parser.parse_args()
+    except Exception as e:
+        print(f"parse args error: {e}")
+        # because we hook sys.exit in hook.py and raise a exception, the exit will be reset to 1.
+        # parser origin exit code is 2. so we use 2 here.
+        sys.exit(2)
 
     address: str = args.address
     session_id: str = str(args.session_id)
     output: Literal["console", "file"] = args.output
     package: str | None = args.package
-    suffix: str | None = args.suffix
     session_dir: str = args.session_dir
+    identifier: str | None = args.identifier
 
-    config_logger(session_id, suffix, output)
+    config_logger(session_id, identifier, output)
 
-    run_async_code(run_executor(address=address, session_id=session_id, package=package, session_dir=session_dir, suffix=suffix))
+    run_async_code(run_executor(address=address, session_id=session_id, package=package, session_dir=session_dir, identifier=identifier))
 
 if __name__ == '__main__':
     main()
\ No newline at end of file
